// dip_arithmetic.c
// for NerdKits with ATmega168
// hevans@mit.edu

#define F_CPU 14745600

#include <stdio.h>
#include <math.h>

#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <inttypes.h>

#include "../libnerdkits/delay.h"
#include "../libnerdkits/lcd.h"
#include "../libnerdkits/uart.h"

// NOTE: (switches connects to GND when closed, otherwise
// the pin is internally pulled up through a pull-up resistor to VCC)

  // declare the variables
  volatile uint16_t sum = 0;
  volatile uint8_t number;
  volatile uint16_t secret;
  
  uint8_t nIn;
  uint8_t nIn2;

  void button(void);
  void set_secret(void);


int main() {
  // start up the LCD
  lcd_init();
  lcd_home();
  
  // LED as output
  DDRC |= (1<<PC1); // Green
  DDRC |= (1<<PC0); // Red
  
  // Button as Input PB1
  DDRB &= ~(1<<PB1);

  // Set the 4 pins to input mode
  DDRC &= ~(1<<PC2); // set PC2 as input - sets a 0 to PC2
  DDRC &= ~(1<<PC3); // set PC3 as input - sets a 0 to PC3
  DDRC &= ~(1<<PC4); // set PC4 as input - sets a 0 to PC4
  DDRC &= ~(1<<PC5); // set PC5 as input - sets a 0 to PC5

  // turn on the internal resistors - Kodierschalter 1
  PORTC |= (1<<PC2); // turn on internal pull up resistor for PA2
  PORTC |= (1<<PC3); // turn on internal pull up resistor for PA3
  PORTC |= (1<<PC4); // turn on internal pull up resistor for PA4
  PORTC |= (1<<PC5); // turn on internal pull up resistor for PA5
  
  // turn on the internal resistors - Kodierschalter 2
  PORTB |= (1<<PB2); // turn on internal pull up resistor for PA2
  PORTB |= (1<<PB3); // turn on internal pull up resistor for PA3
  PORTB |= (1<<PB4); // turn on internal pull up resistor for PA4
  PORTB |= (1<<PB5); // turn on internal pull up resistor for PA5
  
  // turn on the internal resistors - Button
  PORTB |= (1<<PB1); // turn on internal pull up resistor
  
  
  while(1) {
  
	  nIn = ~(PINC >> 2) & 0x0F; // Kodierschalter 1
	  nIn2 = ~(PINB >> 2) & 0x0F; // Kodierschalter 2
	  
	  set_secret();
	  
	  if(!(PINB & (1<<PB1))) // When Button is pressed
	  { 
		number=1;
		button();		
      }
	  
	  if(secret==sum)
	  {
			// turn on Green LED
			PORTC |= (1<<PC1);
			
			// turn off Red LED
			PORTC &= ~(1<<PC0);	
	  }

	   else if(secret!=sum)
	   {
			// turn on Red LED
			PORTC |= (1<<PC0);
			
			// turn off Green LED
			PORTC &= ~(1<<PC1);
	   }
	  
	  // Die Buttuns sind an PC2. PC3, PC4 und PC5 angeschlossen.
	  // Zu Beginn hat PINC somit 111100 (dezimal 60)  -- Die fhrende Null des PINC von PINC6 kann/muss weggelassen werden, da es "nur" ein 0 ist. Eine 1 msste geschrieben werden.
	  // Wenn der Button an PC2 gedrckt wird dann hat PINC 111000 (dezimal 56)
	  // Danach muss man invertieren. PINC 11000111 (dezimal 199) 
	  // PINC >> 2 bedeutet, dass um 2 Stellen nach rechts verschoben wird. Dies geschieht mit 1er. Nun ist PINC 11110001 (dezimal 241)
	  // Anschlieend muss mit einem logischen UND addiert werden. Hier wird 11110001 mit 00001111 addiert. Dies wird gemacht, weil uns (von rechts) nur die ersten 4 Stellen interessieren.
	  // Bei dieser Addition kommt 00000001 raus. Es kommt also dezimal eine 1 heraus, welche auf dem Kodierschalter eingestellt wurde.
	  
      lcd_home();
	  lcd_write_string(PSTR("SecTeil1: "));
	  lcd_write_int16(nIn);
	  lcd_write_string(PSTR("        "));
	  
	  lcd_line_two();
	  lcd_write_string(PSTR("SecTeil2: "));
	  lcd_write_int16(nIn2);
	  lcd_write_string(PSTR("        "));
	  
	  lcd_line_three();
	  lcd_write_string(PSTR("Bt Sum: "));
	  lcd_write_int16(sum);
	  lcd_write_string(PSTR("        "));
	  
	  lcd_line_four();
	  lcd_write_string(PSTR("Sec Sum: "));
	  lcd_write_int16(secret);
	  lcd_write_string(PSTR("        "));
	  
  }
  return 0;
}

void button(void)
{
	if(sum==0)
	{
		sum=number;
		delay_ms(120);
					}

	else if(sum > 0 && sum <= 9)
	{	
		sum=(sum*10)+number;
		delay_ms(120);
	}
	
	else if(sum > 9 && sum <= 99)
	{
		/*
		if(secret==sum)
		{
			// turn on Green LED
			PORTC |= (1<<PC1);
			
			// turn off Red LED
			PORTC &= ~(1<<PC0);	
		}

	   else if(secret!=sum)
	   {
			// turn on Red LED
			PORTC |= (1<<PC0);
			
			// turn off Green LED
			PORTC &= ~(1<<PC1);
	   }
	   */
	}
}

void set_secret(void)
{
	secret = (nIn*10) + nIn2;
}
